@@ -19,7 +19,7 @@ from xrspatial.utils import height_implied_by_aspect_ratio
 
 from mapshader.mercator import MercatorTileDefinition
 from mapshader.sources import MapSource
-
+from .multifile import MultiFileRaster
 
 import spatialpandas
 
@@ -76,7 +76,13 @@ def create_agg(source: MapSource,
     agg_func = source.agg_func
     geometry_type = source.geometry_type
 
-    if z and z in source.overviews:
+    if isinstance(source.data, MultiFileRaster):
+        dataset = source.data.load_overview(z, source.band)
+        # Note this is really an xr.DataArray.
+        if dataset is None:
+            dataset = source.data.load_bounds(xmin, ymin, xmax, ymax, source.band,
+                                              source.transforms)
+    elif z and z in source.overviews:
         print(f'Using overview: {z}', file=sys.stdout)
         dataset = source.overviews[z]
     else:
@@ -183,13 +189,6 @@ def polygon_aggregation(cvs, data, zfield, agg_func):
         return cvs.polygons(data, 'geometry')
 
 
-def get_data_array_extent(dataarray):
-    return (dataarray.coords['x'].min().item(),
-            dataarray.coords['y'].min().item(),
-            dataarray.coords['x'].max().item(),
-            dataarray.coords['y'].max().item())
-
-
 def raster_aggregation(cvs, data, interpolate='linear', padding=0, agg_method=rd.max()):
     """
     Sample a raster dataset by canvas size and bounds.
@@ -537,7 +536,7 @@ def render_map(source: MapSource,  # noqa: C901
         width = height_implied_by_aspect_ratio(height, y_range, x_range)
 
     # handle out of bounds
-    if xmin < sxmin and ymin < symin and xmax > symax and ymax > symax:
+    if xmax < sxmin or ymax < symin or xmin > symax or ymin > symax:
         agg = tf.Image(np.zeros(shape=(height, width), dtype=np.uint32),
                        coords={'x': np.linspace(xmin, xmax, width),
                                'y': np.linspace(ymin, ymax, height)},
@@ -652,3 +651,23 @@ def render_legend(source: MapSource):
     geojson : string
     """
     return json.dumps(get_legend(source))
+
+
+def render_services(services: list):
+    """
+    Get the MapService dictionary representation and return as a JSON string.
+
+    Parameters
+    ----------
+    services : List of mapshader.service.MapService
+        The input datasource.
+
+    Returns
+    -------
+    geojson : string
+    """
+    service_list = []
+    for service in services:
+        service_list.append(service.to_dict())
+
+    return json.dumps(service_list)
