@@ -1,4 +1,5 @@
 from functools import partial
+from os import path
 import sys
 
 from bokeh.models.sources import GeoJSONDataSource
@@ -24,6 +25,7 @@ from mapshader import hello
 from mapshader.core import render_map
 from mapshader.core import render_geojson
 from mapshader.core import render_legend
+from mapshader.core import render_services
 
 from mapshader.services import get_services, MapService
 
@@ -31,7 +33,10 @@ from mapshader.sources import MapSource
 
 from mapshader.utils import psutil_fetching
 
-jinja2_env = Environment(loader=FileSystemLoader("mapshader/templates/"))
+HERE = path.abspath(path.dirname(__file__))
+TEMPLATE_DIR = path.join(HERE, 'templates')
+jinja2_env = Environment(loader=FileSystemLoader(TEMPLATE_DIR))
+
 
 def flask_to_tile(source: MapSource, z=0, x=0, y=0):
 
@@ -86,6 +91,11 @@ def flask_to_legend(source: MapSource):
     return resp
 
 
+def flask_to_services(services: list):
+    resp = render_services(services)
+    return resp
+
+
 def build_previewer(service: MapService):
     '''Helper function for creating a simple Bokeh figure with
     a WMTS Tile Source.
@@ -187,6 +197,7 @@ def configure_app(app: Flask, user_source_filepath=None, contains=None):
                          partial(service_page, service=service))
 
     app.add_url_rule('/', 'home', partial(index_page, services=services))
+    app.add_url_rule('/services', 'services', partial(flask_to_services, services=services))
     app.add_url_rule('/psutil', 'psutil', psutil_fetching)
 
     hello(services)
@@ -214,4 +225,5 @@ if __name__ == '__main__':
     if user_file:
         user_file = path.abspath(path.expanduser(user_file))
 
-    app = create_app(user_file, contains=service_grep).run(host='0.0.0.0', debug=debug)
+    app = create_app(user_file, contains=service_grep).run(
+        host='0.0.0.0', debug=False)
