@@ -10,11 +10,12 @@ from mapshader.colors import colors
 from mapshader.io import load_raster
 from mapshader.io import load_vector
 from mapshader.transforms import get_transform_by_name
+from .multifile import MultiFileRaster
 
 import spatialpandas
 
 
-class MapSource(object):
+class MapSource:
     """
     This class represents a map source object.
 
@@ -94,6 +95,8 @@ class MapSource(object):
         'polygon_to_line', and 'raster_to_categorical_points'.
     preload : bool, default=False
         Preload the data after the service started.
+    force_recreate_overviews : bool, default=False
+        For overviews to be recreated even if they already exist.
     """
 
     def __init__(self,  # noqa: C901
@@ -128,8 +131,10 @@ class MapSource(object):
                  default_width=256,
                  overviews=None,
                  transforms=None,
+                 band=None,
                  attrs=None,
-                 preload=False):
+                 preload=False,
+                 force_recreate_overviews=False):
 
         if fields is None and isinstance(data, (gpd.GeoDataFrame)):
             fields = [geometry_field]
@@ -196,6 +201,8 @@ class MapSource(object):
         self.default_height = default_height
         self.preload = preload
         self.geometry_field = geometry_field
+        self.band = band
+        self.force_recreate_overviews = force_recreate_overviews
 
         self.is_loaded = False
         self.data = data
@@ -210,9 +217,6 @@ class MapSource(object):
     def load_func(self):
         raise NotImplementedError()
 
-    def get_full_extent(self):
-        raise NotImplementedError()
-
     def load(self):
         """
         Load the service data.
@@ -243,7 +247,7 @@ class MapSource(object):
                 print('Using Given Filepath unmodified: config{self.config_file}', file=sys.stdout)
                 data_path = self.filepath
 
-            data = self.load_func(data_path)
+            data = self.load_func(data_path, self.transforms, self.force_recreate_overviews)
         else:
             data = self.data
 
@@ -259,7 +263,8 @@ class MapSource(object):
         if self.is_loaded:
             return self
 
-        self._apply_transforms()
+        if not isinstance(self.data, MultiFileRaster):
+            self._apply_transforms()
 
         self.is_loaded = True
 
@@ -318,10 +323,13 @@ class RasterSource(MapSource):
     @property
     @memoized()
     def full_extent(self):
-        return (self.data.coords['x'].min().compute().item(),
-                self.data.coords['y'].min().compute().item(),
-                self.data.coords['x'].max().compute().item(),
-                self.data.coords['y'].max().compute().item())
+        if hasattr(self.data, "full_extent"):
+            return self.data.full_extent()
+        else:
+            return (self.data.coords['x'].min().compute().item(),
+                    self.data.coords['y'].min().compute().item(),
+                    self.data.coords['x'].max().compute().item(),
+                    self.data.coords['y'].max().compute().item())
 
 
 class VectorSource(MapSource):
@@ -505,11 +513,14 @@ def elevation_source():
     orient_transform = dict(name='orient_array')
     flip_transform = dict(name='flip_coords', args=dict(dim='y'))
     reproject_transform = dict(name='reproject_raster', args=dict(epsg=3857))
+    overviews_transform = dict(name='build_raster_overviews',
+                               args=dict(levels={'2': 1250, '3': 650}))
     transforms = [squeeze_transform,
                   cast_transform,
                   orient_transform,
                   flip_transform,
-                  reproject_transform]
+                  reproject_transform,
+                  overviews_transform]
 
     # construct value obj
     source_obj = dict()
